@@ -1,23 +1,35 @@
-use super::easy_mark_parser as easy_mark;
+use bevy::prelude::EventWriter;
 use bevy_egui::egui::*;
+use crate::egui::EasyLinkEvent;
+
+use super::easy_mark_parser as easy_mark;
 
 /// Parse and display a VERY simple and small subset of Markdown.
-pub fn easy_mark(ui: &mut Ui, easy_mark: &str) {
-    easy_mark_it(ui, easy_mark::Parser::new(easy_mark))
+pub fn easy_mark(ui: &mut Ui, easy_mark: &str, link_evts: &mut EventWriter<EasyLinkEvent>) {
+    easy_mark_it(ui, easy_mark::Parser::new(easy_mark), link_evts);
 }
 
-pub fn easy_mark_it<'em>(ui: &mut Ui, items: impl Iterator<Item = easy_mark::Item<'em>>) {
-    ui.horizontal_wrapped(|ui| {
+pub fn easy_mark_it<'em>(ui: &mut Ui, items: impl Iterator<Item = easy_mark::Item<'em>>, link_evts: &mut EventWriter<EasyLinkEvent>) {
+    let initial_size = vec2(
+        ui.available_width(),
+        ui.spacing().interact_size.y, // Assume there will be
+    );
+
+    let layout = Layout::left_to_right()
+        .with_main_wrap(true)
+        .with_cross_align(Align::BOTTOM);
+
+    ui.allocate_ui_with_layout(initial_size, layout, |ui| {
         ui.spacing_mut().item_spacing.x = 0.0;
         ui.set_row_height(ui.fonts()[TextStyle::Body].row_height());
 
         for item in items {
-            item_ui(ui, item);
+            item_ui(ui, item, link_evts);
         }
     });
 }
 
-pub fn item_ui(ui: &mut Ui, item: easy_mark::Item<'_>) {
+pub fn item_ui(ui: &mut Ui, item: easy_mark::Item<'_>, link_evts: &mut EventWriter<EasyLinkEvent>) {
     let row_height = ui.fonts()[TextStyle::Body].row_height();
     let one_indent = row_height / 2.0;
 
@@ -30,11 +42,14 @@ pub fn item_ui(ui: &mut Ui, item: easy_mark::Item<'_>) {
         }
 
         easy_mark::Item::Text(style, text) => {
-            ui.add(label_from_style(text, &style));
+            ui.label(rich_text_from_style(text, &style));
         }
         easy_mark::Item::Hyperlink(style, text, url) => {
-            let label = label_from_style(text, &style);
+            /*
+            let label = rich_text_from_style(text, &style);
             ui.add(Hyperlink::from_label_and_url(label, url));
+             */
+            crate::egui::EasyLink::new(url, text, style).ui(ui, link_evts);
         }
 
         easy_mark::Item::Separator => {
@@ -78,7 +93,7 @@ pub fn item_ui(ui: &mut Ui, item: easy_mark::Item<'_>) {
     };
 }
 
-pub fn label_from_style(text: &str, style: &easy_mark::Style) -> Label {
+pub fn rich_text_from_style(text: &str, style: &easy_mark::Style) -> RichText {
     let easy_mark::Style {
         heading,
         quoted,
@@ -93,34 +108,34 @@ pub fn label_from_style(text: &str, style: &easy_mark::Style) -> Label {
 
     let small = small || raised; // Raised text is also smaller
 
-    let mut label = Label::new(text);
+    let mut rich_text = RichText::new(text);
     if heading && !small {
-        label = label.heading().strong();
+        rich_text = rich_text.heading().strong();
     }
     if small && !heading {
-        label = label.small();
+        rich_text = rich_text.small();
     }
     if code {
-        label = label.code();
+        rich_text = rich_text.code();
     }
     if strong {
-        label = label.strong();
+        rich_text = rich_text.strong();
     } else if quoted {
-        label = label.weak();
+        rich_text = rich_text.weak();
     }
     if underline {
-        label = label.underline();
+        rich_text = rich_text.underline();
     }
     if strikethrough {
-        label = label.strikethrough();
+        rich_text = rich_text.strikethrough();
     }
     if italics {
-        label = label.italics();
+        rich_text = rich_text.italics();
     }
     if raised {
-        label = label.raised();
+        rich_text = rich_text.raised();
     }
-    label
+    rich_text
 }
 
 fn bullet_point(ui: &mut Ui, width: f32) -> Response {
