@@ -24,11 +24,8 @@ impl SingleShape<shapes::Circle> for FillCircle {
             radius: self.radius,
         }
     }
-    fn get_colors(&self) -> ShapeColors {
-        ShapeColors::new(self.color)
-    }
     fn get_draw_mode(&self) -> DrawMode {
-        DrawMode::Fill(FillOptions::default())
+        DrawMode::Fill(FillMode::color(self.color))
     }
     fn get_transform(&self) -> Transform {
         if self.radius <= 0.0 {
@@ -58,11 +55,8 @@ impl SingleShape<shapes::Circle> for StrokeCircle {
             radius: self.radius,
         }
     }
-    fn get_colors(&self) -> ShapeColors {
-        ShapeColors::new(self.color)
-    }
     fn get_draw_mode(&self) -> DrawMode {
-        DrawMode::Stroke(StrokeOptions::default().with_line_width(self.line_width))
+        DrawMode::Stroke(StrokeMode::new(self.color, self.line_width))
     }
     fn get_transform(&self) -> Transform {
         if self.radius <= 0.0 {
@@ -93,21 +87,14 @@ impl SingleShape<shapes::Circle> for OutlineCircle {
             radius: self.radius,
         }
     }
-    fn get_colors(&self) -> ShapeColors {
-        if self.outline_width > 0.0 {
-            ShapeColors::outlined(self.color, self.outline_color)
-        } else {
-            ShapeColors::new(self.color)
-        }
-    }
     fn get_draw_mode(&self) -> DrawMode {
         if self.outline_width > 0.0 {
             DrawMode::Outlined {
-                fill_options: FillOptions::default(),
-                outline_options: StrokeOptions::default().with_line_width(self.outline_width),
+                fill_mode: FillMode::color(self.color),
+                outline_mode: StrokeMode::new(self.outline_color, self.outline_width),
             }
         } else {
-            DrawMode::Fill(FillOptions::default())
+            DrawMode::Fill(FillMode::color(self.color))
         }
     }
     fn get_transform(&self) -> Transform {
