@@ -5,6 +5,7 @@ use super::BevyUtil;
 
 impl BevyUtil {
     pub fn rgb_to_egui(color: &Color) -> Hsva {
-        Hsva::from_rgb([color.r(), color.g(), color.b()])
+        let v = color.as_linear_rgba_f32();
+        Hsva::from_rgb([v[0], v[1], v[2]])
     }
 }
